@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: m_nick.c 23853 2007-04-22 14:09:34Z jilles $
+ *  $Id: m_nick.c 23995 2007-07-17 02:37:06Z androsyn $
  */
 
 #include "stdinc.h"
@@ -77,7 +77,7 @@ struct Message save_msgtab = {
 };
 
 mapi_clist_av1 nick_clist[] = { &nick_msgtab, &uid_msgtab, &save_msgtab, NULL };
-DECLARE_MODULE_AV1(nick, NULL, NULL, nick_clist, NULL, NULL, "$Revision: 23853 $");
+DECLARE_MODULE_AV1(nick, NULL, NULL, nick_clist, NULL, NULL, "$Revision: 23995 $");
 
 static int change_remote_nick(struct Client *, struct Client *, time_t, const char *, int);
 
@@ -1122,7 +1122,8 @@ register_client(struct Client *client_p, struct Client *server,
 		return exit_client(source_p, source_p, &me, "USER server wrong direction");
 	}
 
-	return (introduce_client(client_p, source_p, user, nick));
+	introduce_client(client_p, source_p, user, nick);
+	return 0;
 }
 
 static void
