@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: client.c 23955 2007-05-14 17:22:36Z leeh $
+ *  $Id: client.c 24473 2007-11-07 17:40:44Z jilles $
  */
 #include "stdinc.h"
 #include "config.h"
@@ -1353,7 +1353,9 @@ exit_unknown_client(struct Client *client_p, struct Client *source_p, struct Cli
 	dlinkDelete(&source_p->localClient->tnode, &unknown_list);
 
 	if(!IsIOError(source_p))
-		sendto_one(source_p, "ERROR :Closing Link: 127.0.0.1 (%s)", comment);
+		sendto_one(source_p, "ERROR :Closing Link: %s (%s)",
+				source_p->user != NULL ? source_p->host : "127.0.0.1",
+				comment);
 
 	close_connection(source_p);
 
