@@ -16,7 +16,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: match.c 23029 2006-09-05 15:17:49Z androsyn $
+ * $Id: match.c 24900 2008-01-11 19:02:50Z androsyn $
  *
  */
 #include "stdinc.h"
@@ -129,6 +129,7 @@ match_esc(const char *mask, const char *name)
 	int wild = 0;
 	int calls = 0;
 	int quote = 0;
+	int match1 = 0;
 
 	s_assert(mask != NULL);
 	s_assert(name != NULL);
@@ -205,8 +206,17 @@ match_esc(const char *mask, const char *name)
 			return (*m == 0);
 		}
 
-		if((!quote && ((*m == '?') || (*m == '@' && IsLetter(*n)) || (*m == '#' && IsDigit(*n)))) ||
-		   (ToLower(*m) == ToLower(*n) && (quote || (*m != '@' && *m != '#'))))
+		if (quote)
+			match1 = *m == 's' ? *n == ' ' : ToLower(*m) == ToLower(*n);
+		else if (*m == '?')
+			match1 = 1;
+		else if (*m == '@')
+			match1 = IsLetter(*n);
+		else if (*m == '#')
+			match1 = IsDigit(*n);
+		else
+			match1 = ToLower(*m) == ToLower(*n);
+		if (match1)
 		{
 			if(*m)  
 				m++;
