@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: s_conf.c 23955 2007-05-14 17:22:36Z leeh $
+ *  $Id: s_conf.c 23963 2007-05-18 19:38:14Z leeh $
  */
 
 #include "stdinc.h"
@@ -899,29 +899,6 @@ validate_conf(void)
  *
  */
 
-/*
- * conf_connect_allowed
- *
- * inputs	- pointer to inaddr
- *		- int type ipv4 or ipv6
- * output	- ban info or NULL
- * side effects	- none
- */
-struct ConfItem *
-conf_connect_allowed(struct sockaddr *addr, int aftype)
-{
-	struct ConfItem *aconf = find_dline(addr, aftype);
-
-	/* DLINE exempt also gets you out of static limits/pacing... */
-	if(aconf && (aconf->status & CONF_EXEMPTDLINE))
-		return NULL;
-
-	if(aconf != NULL)
-		return aconf;
-
-	return NULL;
-}
-
 /* add_temp_kline()
  *
  * inputs        - pointer to struct ConfItem
