@@ -29,7 +29,7 @@
  * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: s_newconf.c 23457 2007-01-14 00:23:40Z androsyn $
+ * $Id: s_newconf.c 24906 2008-01-11 20:04:29Z androsyn $
  */
 
 #include "stdinc.h"
@@ -578,6 +578,23 @@ find_xline(const char *gecos, int counter)
 	return NULL;
 }
 
+struct ConfItem *
+find_xline_mask(const char *gecos)
+{
+	struct ConfItem *aconf;
+	dlink_node *ptr;
+
+	DLINK_FOREACH(ptr, xline_conf_list.head)
+	{
+		aconf = ptr->data;
+
+		if(!irccmp(aconf->name, gecos))
+			return aconf;
+	}
+
+	return NULL;
+}
+
 struct ConfItem *
 find_nick_resv(const char *name)
 {
@@ -598,6 +615,23 @@ find_nick_resv(const char *name)
 	return NULL;
 }
 
+struct ConfItem *
+find_nick_resv_mask(const char *name)
+{
+	struct ConfItem *aconf;
+	dlink_node *ptr;
+
+	DLINK_FOREACH(ptr, resv_conf_list.head)
+	{
+		aconf = ptr->data;
+
+		if(!irccmp(aconf->name, name))
+			return aconf;
+	}
+
+	return NULL;
+}
+
 /* clean_resv_nick()
  *
  * inputs	- nick
