@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: s_user.c 23955 2007-05-14 17:22:36Z leeh $
+ *  $Id: s_user.c 24001 2007-07-17 15:07:43Z androsyn $
  */
 
 #include "stdinc.h"
@@ -552,7 +552,8 @@ register_local_user(struct Client *client_p, struct Client *source_p, const char
 
 	monitor_signon(source_p);
 	user_welcome(source_p);
-	return (introduce_client(client_p, source_p, user, source_p->name));
+	introduce_client(client_p, source_p, user, source_p->name);
+	return 0;
 }
 
 /*
@@ -564,7 +565,7 @@ register_local_user(struct Client *client_p, struct Client *source_p, const char
  *		  of the net, either from a local client connect or
  *		  from a remote connect.
  */
-int
+void
 introduce_client(struct Client *client_p, struct Client *source_p, struct User *user, const char *nick)
 {
 	static char ubuf[12];
@@ -617,9 +618,6 @@ introduce_client(struct Client *client_p, struct Client *source_p, struct User *
 			      (long) source_p->tsinfo,
 			      ubuf, source_p->username, source_p->host,
 			      source_p->servptr->name, source_p->info);
-
-
-	return 0;
 }
 
 /* 
